@@ -1,10 +1,15 @@
+// Copyright 2018 the Kurbo Authors
+// SPDX-License-Identifier: Apache-2.0 OR MIT
+
 //! Bézier paths (up to cubic).
 
 #![allow(clippy::many_single_char_names)]
 
-use std::iter::{Extend, FromIterator};
-use std::mem;
-use std::ops::{Mul, Range};
+use core::iter::{Extend, FromIterator};
+use core::mem;
+use core::ops::{Mul, Range};
+
+use alloc::vec::Vec;
 
 use arrayvec::ArrayVec;
 
@@ -15,6 +20,9 @@ use crate::{
     ParamCurveExtrema, ParamCurveNearest, Point, QuadBez, Rect, Shape, TranslateScale, Vec2,
 };
 
+#[cfg(not(feature = "std"))]
+use crate::common::FloatFuncs;
+
 /// A Bézier path.
 ///
 /// These docs assume basic familiarity with Bézier curves; for an introduction,
@@ -35,6 +43,10 @@ use crate::{
 /// For tasks like drawing, elements are a natural fit, but when doing
 /// hit-testing or subdividing, we need to have access to the segments.
 ///
+/// Conceptually, a `BezPath` contains zero or more subpaths. Each subpath
+/// *always* begins with a `MoveTo`, then has zero or more `LineTo`, `QuadTo`,
+/// and `CurveTo` elements, and optionally ends with a `ClosePath`.
+///
 /// Internally, a `BezPath` is a list of [`PathEl`]s; as such it implements
 /// [`FromIterator<PathEl>`] and [`Extend<PathEl>`]:
 ///
@@ -180,12 +192,25 @@ impl BezPath {
     /// let back_to_path: BezPath = as_vec.into_iter().collect();
     /// ```
     pub fn from_vec(v: Vec<PathEl>) -> BezPath {
+        debug_assert!(
+            v.first().is_none() || matches!(v.first(), Some(PathEl::MoveTo(_))),
+            "BezPath must begin with MoveTo"
+        );
         BezPath(v)
     }
 
+    /// Removes the last [`PathEl`] from the path and returns it, or `None` if the path is empty.
+    pub fn pop(&mut self) -> Option<PathEl> {
+        self.0.pop()
+    }
+
     /// Push a generic path element onto the path.
     pub fn push(&mut self, el: PathEl) {
-        self.0.push(el)
+        self.0.push(el);
+        debug_assert!(
+            matches!(self.0.first(), Some(PathEl::MoveTo(_))),
+            "BezPath must begin with MoveTo"
+        )
     }
 
     /// Push a "move to" element onto the path.
@@ -194,40 +219,70 @@ impl BezPath {
     }
 
     /// Push a "line to" element onto the path.
+    ///
+    /// Will panic with a debug assert when the current subpath does not
+    /// start with `move_to`.
     pub fn line_to<P: Into<Point>>(&mut self, p: P) {
+        debug_assert!(self.is_open_subpath(), "no open subpath (missing MoveTo)");
         self.push(PathEl::LineTo(p.into()));
     }
 
     /// Push a "quad to" element onto the path.
+    ///
+    /// Will panic with a debug assert when the current subpath does not
+    /// start with `move_to`.
     pub fn quad_to<P: Into<Point>>(&mut self, p1: P, p2: P) {
+        debug_assert!(self.is_open_subpath(), "no open subpath (missing MoveTo)");
         self.push(PathEl::QuadTo(p1.into(), p2.into()));
     }
 
     /// Push a "curve to" element onto the path.
+    ///
+    /// Will panic with a debug assert when the current subpath does not
+    /// start with `move_to`.
     pub fn curve_to<P: Into<Point>>(&mut self, p1: P, p2: P, p3: P) {
+        debug_assert!(self.is_open_subpath(), "no open subpath (missing MoveTo)");
         self.push(PathEl::CurveTo(p1.into(), p2.into(), p3.into()));
     }
 
     /// Push a "close path" element onto the path.
+    ///
+    /// Will panic with a debug assert when the current subpath does not
+    /// start with `move_to`.
     pub fn close_path(&mut self) {
+        debug_assert!(self.is_open_subpath(), "no open subpath (missing MoveTo)");
         self.push(PathEl::ClosePath);
     }
 
+    fn is_open_subpath(&self) -> bool {
+        !self.0.is_empty() && self.0.last() != Some(&PathEl::ClosePath)
+    }
+
     /// Get the path elements.
     pub fn elements(&self) -> &[PathEl] {
         &self.0
     }
 
+    /// Get the path elements (mut version).
+    pub fn elements_mut(&mut self) -> &mut [PathEl] {
+        &mut self.0
+    }
+
     /// Returns an iterator over the path's elements.
-    pub fn iter(&self) -> impl Iterator<Item = PathEl> + '_ {
+    pub fn iter(&self) -> impl Iterator<Item = PathEl> + Clone + '_ {
         self.0.iter().copied()
     }
 
     /// Iterate over the path segments.
-    pub fn segments(&self) -> impl Iterator<Item = PathSeg> + '_ {
+    pub fn segments(&self) -> impl Iterator<Item = PathSeg> + Clone + '_ {
         segments(self.iter())
     }
 
+    /// Shorten the path, keeping the first `len` elements.
+    pub fn truncate(&mut self, len: usize) {
+        self.0.truncate(len);
+    }
+
     /// Flatten the path, invoking the callback repeatedly.
     ///
     /// Flattening is the action of approximating a curve with a succession of line segments.
@@ -302,8 +357,14 @@ impl BezPath {
 
     /// Get the segment at the given element index.
     ///
-    /// The element index counts [`PathEl`] elements, so
-    /// for example includes an initial `Moveto`.
+    /// If you need to access all segments, [`segments`] provides a better
+    /// API. This is intended for random access of specific elements, for clients
+    /// that require this specifically.
+    ///
+    /// **note**: This returns the segment that ends at the provided element
+    /// index. In effect this means it is *1-indexed*: since no segment ends at
+    /// the first element (which is presumed to be a `MoveTo`) `get_seg(0)` will
+    /// always return `None`.
     pub fn get_seg(&self, ix: usize) -> Option<PathSeg> {
         if ix == 0 || ix >= self.0.len() {
             return None;
@@ -320,7 +381,9 @@ impl BezPath {
             PathEl::QuadTo(p1, p2) => Some(PathSeg::Quad(QuadBez::new(last, p1, p2))),
             PathEl::CurveTo(p1, p2, p3) => Some(PathSeg::Cubic(CubicBez::new(last, p1, p2, p3))),
             PathEl::ClosePath => self.0[..ix].iter().rev().find_map(|el| match *el {
-                PathEl::MoveTo(start) => Some(PathSeg::Line(Line::new(last, start))),
+                PathEl::MoveTo(start) if start != last => {
+                    Some(PathSeg::Line(Line::new(last, start)))
+                }
                 _ => None,
             }),
             _ => None,
@@ -367,7 +430,7 @@ impl FromIterator<PathEl> for BezPath {
 /// slice, as it returns `PathEl` items, rather than references.
 impl<'a> IntoIterator for &'a BezPath {
     type Item = PathEl;
-    type IntoIter = std::iter::Cloned<std::slice::Iter<'a, PathEl>>;
+    type IntoIter = core::iter::Cloned<core::slice::Iter<'a, PathEl>>;
 
     fn into_iter(self) -> Self::IntoIter {
         self.elements().iter().cloned()
@@ -376,7 +439,7 @@ impl<'a> IntoIterator for &'a BezPath {
 
 impl IntoIterator for BezPath {
     type Item = PathEl;
-    type IntoIter = std::vec::IntoIter<PathEl>;
+    type IntoIter = alloc::vec::IntoIter<PathEl>;
 
     fn into_iter(self) -> Self::IntoIter {
         self.0.into_iter()
@@ -587,6 +650,7 @@ where
 /// An iterator that transforms path elements to path segments.
 ///
 /// This struct is created by the [`segments`] function.
+#[derive(Clone)]
 pub struct Segments<I: Iterator<Item = PathEl>> {
     elements: I,
     start_last: Option<(Point, Point)>,
@@ -738,6 +802,15 @@ impl ParamCurveExtrema for PathSeg {
 }
 
 impl PathSeg {
+    /// Get the [`PathEl`] that is equivalent to discarding the segment start point.
+    pub fn as_path_el(&self) -> PathEl {
+        match self {
+            PathSeg::Line(line) => PathEl::LineTo(line.p1),
+            PathSeg::Quad(q) => PathEl::QuadTo(q.p1, q.p2),
+            PathSeg::Cubic(c) => PathEl::CurveTo(c.p1, c.p2, c.p3),
+        }
+    }
+
     /// Returns a new `PathSeg` describing the same path as `self`, but with
     /// the points reversed.
     pub fn reverse(&self) -> PathSeg {
@@ -1015,6 +1088,51 @@ impl PathSeg {
             t2,
         }
     }
+
+    /// Compute endpoint tangents of a path segment.
+    ///
+    /// This version is robust to the path segment not being a regular curve.
+    pub(crate) fn tangents(&self) -> (Vec2, Vec2) {
+        const EPS: f64 = 1e-12;
+        match self {
+            PathSeg::Line(l) => {
+                let d = l.p1 - l.p0;
+                (d, d)
+            }
+            PathSeg::Quad(q) => {
+                let d01 = q.p1 - q.p0;
+                let d0 = if d01.hypot2() > EPS { d01 } else { q.p2 - q.p0 };
+                let d12 = q.p2 - q.p1;
+                let d1 = if d12.hypot2() > EPS { d12 } else { q.p2 - q.p0 };
+                (d0, d1)
+            }
+            PathSeg::Cubic(c) => {
+                let d01 = c.p1 - c.p0;
+                let d0 = if d01.hypot2() > EPS {
+                    d01
+                } else {
+                    let d02 = c.p2 - c.p0;
+                    if d02.hypot2() > EPS {
+                        d02
+                    } else {
+                        c.p3 - c.p0
+                    }
+                };
+                let d23 = c.p3 - c.p2;
+                let d1 = if d23.hypot2() > EPS {
+                    d23
+                } else {
+                    let d13 = c.p3 - c.p1;
+                    if d13.hypot2() > EPS {
+                        d13
+                    } else {
+                        c.p3 - c.p0
+                    }
+                };
+                (d0, d1)
+            }
+        }
+    }
 }
 
 impl LineIntersection {
@@ -1071,10 +1189,10 @@ impl From<QuadBez> for PathSeg {
 }
 
 impl Shape for BezPath {
-    type PathElementsIter = std::vec::IntoIter<PathEl>;
+    type PathElementsIter<'iter> = core::iter::Copied<core::slice::Iter<'iter, PathEl>>;
 
-    fn path_elements(&self, _tolerance: f64) -> Self::PathElementsIter {
-        self.0.clone().into_iter()
+    fn path_elements(&self, _tolerance: f64) -> Self::PathElementsIter<'_> {
+        self.0.iter().copied()
     }
 
     fn to_path(&self, _tolerance: f64) -> BezPath {
@@ -1139,11 +1257,53 @@ impl PathEl {
 ///
 /// If the slice starts with `LineTo`, `QuadTo`, or `CurveTo`, it will be treated as a `MoveTo`.
 impl<'a> Shape for &'a [PathEl] {
-    type PathElementsIter = std::iter::Cloned<std::slice::Iter<'a, PathEl>>;
+    type PathElementsIter<'iter>
+
+    = core::iter::Copied<core::slice::Iter<'a, PathEl>> where 'a: 'iter;
 
     #[inline]
-    fn path_elements(&self, _tolerance: f64) -> Self::PathElementsIter {
-        self.iter().cloned()
+    fn path_elements(&self, _tolerance: f64) -> Self::PathElementsIter<'_> {
+        self.iter().copied()
+    }
+
+    fn to_path(&self, _tolerance: f64) -> BezPath {
+        BezPath::from_vec(self.to_vec())
+    }
+
+    /// Signed area.
+    fn area(&self) -> f64 {
+        segments(self.iter().copied()).area()
+    }
+
+    fn perimeter(&self, accuracy: f64) -> f64 {
+        segments(self.iter().copied()).perimeter(accuracy)
+    }
+
+    /// Winding number of point.
+    fn winding(&self, pt: Point) -> i32 {
+        segments(self.iter().copied()).winding(pt)
+    }
+
+    fn bounding_box(&self) -> Rect {
+        segments(self.iter().copied()).bounding_box()
+    }
+
+    #[inline]
+    fn as_path_slice(&self) -> Option<&[PathEl]> {
+        Some(self)
+    }
+}
+
+/// Implements [`Shape`] for an array of [`PathEl`], provided that the first element of the array is
+/// not a `PathEl::ClosePath`. If it is, several of these functions will panic.
+///
+/// If the array starts with `LineTo`, `QuadTo`, or `CurveTo`, it will be treated as a `MoveTo`.
+impl<const N: usize> Shape for [PathEl; N] {
+    type PathElementsIter<'iter> = core::iter::Copied<core::slice::Iter<'iter, PathEl>>;
+
+    #[inline]
+    fn path_elements(&self, _tolerance: f64) -> Self::PathElementsIter<'_> {
+        self.iter().copied()
     }
 
     fn to_path(&self, _tolerance: f64) -> BezPath {
@@ -1181,7 +1341,7 @@ pub struct PathSegIter {
 }
 
 impl Shape for PathSeg {
-    type PathElementsIter = PathSegIter;
+    type PathElementsIter<'iter> = PathSegIter;
 
     #[inline]
     fn path_elements(&self, _tolerance: f64) -> PathSegIter {
@@ -1238,14 +1398,16 @@ impl Iterator for PathSegIter {
 
 #[cfg(test)]
 mod tests {
+    use crate::{Circle, DEFAULT_ACCURACY};
+
     use super::*;
 
     fn assert_approx_eq(x: f64, y: f64) {
-        assert!((x - y).abs() < 1e-8, "{} != {}", x, y);
+        assert!((x - y).abs() < 1e-8, "{x} != {y}");
     }
 
     #[test]
-    #[should_panic(expected = "Can't start a segment on a ClosePath")]
+    #[should_panic(expected = "no open subpath")]
     fn test_elements_to_segments_starts_on_closepath() {
         let mut path = BezPath::new();
         path.close_path();
@@ -1267,26 +1429,12 @@ mod tests {
     }
 
     #[test]
-    fn test_elements_to_segments_starts_on_quad() {
+    #[should_panic(expected = "no open subpath")]
+    fn test_must_not_start_on_quad() {
         let mut path = BezPath::new();
         path.quad_to((5.0, 5.0), (10.0, 10.0));
         path.line_to((15.0, 15.0));
         path.close_path();
-
-        let mut segments = path.segments();
-        assert_eq!(
-            segments.next(),
-            Some(QuadBez::new((10.0, 10.0), (5.0, 5.0), (10.0, 10.0)).into()),
-        );
-        assert_eq!(
-            segments.next(),
-            Some(Line::new((10.0, 10.0), (15.0, 15.0)).into()),
-        );
-        assert_eq!(
-            segments.next(),
-            Some(Line::new((15.0, 15.0), (10.0, 10.0)).into()),
-        );
-        assert_eq!(segments.next(), None);
     }
 
     #[test]
@@ -1340,4 +1488,15 @@ mod tests {
         assert_eq!(path.winding(Point::new(1.0, 0.5)), -1);
         assert!(path.contains(Point::new(1.0, 0.5)));
     }
+
+    // get_seg(i) should produce the same results as path_segments().nth(i - 1).
+    #[test]
+    fn test_get_seg() {
+        let circle = Circle::new((10.0, 10.0), 2.0).to_path(DEFAULT_ACCURACY);
+        let segments = circle.path_segments(DEFAULT_ACCURACY).collect::<Vec<_>>();
+        let get_segs = (1..usize::MAX)
+            .map_while(|i| circle.get_seg(i))
+            .collect::<Vec<_>>();
+        assert_eq!(segments, get_segs);
+    }
 }
